---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''
---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Output when using `jupynium` command**
If you launch Jupynium server using the command line program, it gives you more helpful logs.

<details>
<code>

Paste the output here

</code>
</details>

**Output of `jupynium --version`**

```
Paste the output here
```

**Output of `nvim --version`**

```
Paste your output here
```

**Additional context**
Add any other context about the problem here.
